pub struct Identity { /* private fields */ }Expand description
Represents a client certificate and its associated data for mutual TLS authentication.
Identity encapsulates the client certificate, its password.
It’s used to authenticate the client to the server during the
TLS handshake.
Examples
use deboa::cert::Identity;
// Load a DER encoded PKCS#12 archive from a slice of bytes using a password
let cert = Identity::from_pkcs12(
&[1, 2, 3],
Some("cert-password".to_string()),
);
// Load a DER encoded certificate and key from a slice of bytes
let cert_with_ca = Identity::from_pkcs8(
&[1, 2, 3],
&[4, 5, 6],
ContentEncoding::DER,
);
Implementations
Sourceimpl Identity
impl Identity
Sourcepub fn from_pkcs8(cert: &[u8], key: &[u8], encoding: ContentEncoding) -> Self
pub fn from_pkcs8(cert: &[u8], key: &[u8], encoding: ContentEncoding) -> Self
pub fn from_pkcs8_file( cert: &str, key: &str, encoding: ContentEncoding, ) -> Result<Self>